betty.test_utils.model package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.model package

## Module contents

Test utilities for `betty.model`.

class betty.test_utils.model.DummyEntity

  Bases: `DummyPlugin`, `Entity`

  A dummy entity.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.

class betty.test_utils.model.DummyUserFacingEntity

  Bases: `UserFacingEntity`, `DummyEntity`

  A dummy user-facing entity.

class betty.test_utils.model.EntityTestBase

  Bases: `PluginTestBase`[`Entity`]

  A base class for testing `betty.model.Entity` implementations.

  async get_sut_instances() → Sequence[Entity]

    Get instances of the entity type under test.

  async test_label() → None

    Tests `betty.model.Entity.label()` implementations.

  async test_plugin_label_plural() → None

    Tests `betty.model.Entity.plugin_label_plural()` implementations.